import { writable } from "svelte/store";
import { openDB, DBSchema } from 'idb';

interface Image {
  name: string,
  filename: string
  lastModified: number
  type: string
  data: ArrayBuffer
}

interface ImageDB extends DBSchema {
  images: {
    value: Image;
    key: string;
    indexes: { 'filename': string };
  };
}


const db = openDB<ImageDB>('Images', 1, {
  upgrade(db) {
    // Create a store of objects
    const store = db.createObjectStore('images', {
      // The 'id' property of the object will be the key.
      keyPath: 'id',
      // If it isn't explicitly set, create a value by auto incrementing.
      autoIncrement: true,
    });
    // Create an index on the 'date' property of the objects.
    store.createIndex('filename', 'filename');
  },
});



const store = writable<Image[]>([]);

async function add(img: Image | Image[]) {

  const images = Array.isArray(img) ? [...img] : [img];

  const tx = (await db).transaction('images', 'readwrite');

  await Promise.all(images.map(img => tx.store.add(img)));

  await tx.done;

}

async function get(name: string): Promise<Image> {
  return new Promise((res, rej) => {
    res({} as Image);
  })
}

async function getAll(): Promise<Image[]> {
  return (await db).getAll("images");
}

(async () => store.set(await getAll()))()

export { store, add, get, getAll };